summaryrefslogtreecommitdiff
path: root/src/mem/xbar.hh
diff options
context:
space:
mode:
Diffstat (limited to 'src/mem/xbar.hh')
-rw-r--r--src/mem/xbar.hh11
1 files changed, 6 insertions, 5 deletions
diff --git a/src/mem/xbar.hh b/src/mem/xbar.hh
index 2b7e7ed48..abe2a1096 100644
--- a/src/mem/xbar.hh
+++ b/src/mem/xbar.hh
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2011-2015 ARM Limited
+ * Copyright (c) 2011-2015, 2018 ARM Limited
* All rights reserved
*
* The license below extends only to copyright in the software and shall
@@ -342,13 +342,14 @@ class BaseXBar : public MemObject
*/
virtual void recvRangeChange(PortID master_port_id);
/** Find which port connected to this crossbar (if any) should be
* given a packet with this address.
*
* @param addr Address to find port for.
* @return id of port that the packet should be sent out of.
*/
- PortID findPort(Addr addr);
+ PortID findPort(AddrRange addr_range);
/**
* Return the address ranges the crossbar is responsible for.
@@ -342,13 +342,14 @@ class BaseXBar : public MemObject
*/
virtual void recvRangeChange(PortID master_port_id);
- /** Find which port connected to this crossbar (if any) should be
- * given a packet with this address.
+ /**
+ * Find which port connected to this crossbar (if any) should be
+ * given a packet with this address range.
*
@@ -342,13 +342,14 @@ class BaseXBar : public MemObject
*
- * @param addr Address to find port for.
+ * @param addr_range Address range to find port for.
* @return id of port that the packet should be sent out of.
*/